nbdev_cards
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

A deck of cards demo of [nbdev](https://nbdev.fast.ai) based on ideas
from “Think Python 2nd Edition” by Allen B. Downey.

## Install

`pip install nbdev-cards2022`

or

`conda install -c fastai nbdev-cards2022`

## How to use

This lib provids a
[Card](https://hdocmsu.github.io/nbdev-cards/nbdev_cards.card.html#card)
class that you can use to create, display, and compare playing cards.

``` python
Card(2,3)
```

    3♥

``` python
suits
```

    ['♣', '♦', '♥', '♠']

``` python
ranks
```

    [None, 'A', '2', '3', '4', '5', '6', '7', '8', '9', '10', 'J', 'Q', 'K']
